
class HdaAppPhotosorterController < ApplicationController
  def initialize
    @items_per_page = 10
    @services = [['Yahoo! Flickr', 'flickr'],
  		['Photobucket', 'photobucket'],
  		['Google Picasa', 'picasa'],
  		['Photki', 'fotki']]
  end

  def index
    list
  end

  def list
    # this is a standard HDA variable, it shows to the right of
    # the logo
    @page_title = "Photosorter"

    sort = case params['sort']
           when "name"  then "name"
           when "title" then "title"
           when "service"  then "service"
           when "name_reverse"  then "name DESC"
           when "title_reverse"   then "title DESC"
           when "service_reverse" then "service DESC"
           end

    conditions = ["name LIKE ?", "%#{params[:query]}%"] unless params[:query].nil?
    # conditions = ["name LIKE ?", "%#{params[:query]}%"] unless params[:query].nil?

    @total = HdaAppPhotosorter.count(:conditions => conditions)
    @items_pages, @items = paginate :hda_app_photosorters,
				:order => sort,
				:conditions => conditions,
				:per_page => @items_per_page

    if request.xml_http_request?
      render :partial => "items_list", :layout => false
    end

  end

  def selection
    @selected =
      case params[:item_url]
        when /picasaweb/i: 'picasa'
        when /fotki/i: 'fotki'
        when /flickr/i: 'flickr'
        when /photobucket/i: 'photobucket'
        else nil
      end
    if request.xml_http_request?
      render :partial => "selected_service", :layout => false
    end
  end

  def add_item
    unless params[:item].nil?
      album = HdaAppPhotosorter.new
      album.name = params[:item][:name]
      album.service = params[:service_id]
      album.url = params[:item][:url]
      album.save
    end
    self.list
  end

  def go
    if params[:item].nil?
      gen_gallery HdaAppPhotosorter.find(:all)
    else
      gen_gallery [ HdaAppPhotosorter.find(params[:item]) ]
    end
    redirect_to "http://photosorter/"
  end

  def delete
    unless params[:id].nil?
      album = HdaAppPhotosorter.find(params[:id])
      album.destroy
    end
    self.list
  end

  def gen_gallery(albums)
    # FIXME: error checking!
    file = File.new('/var/hda/apps/photosorter/html/gallery.xml', "w")
    
    s = '<?xml version="1.0" encoding="iso-8859-1"?>
  	<gallery>
  	<config>
  		<title>HDAs Photos</title>
  		<thumbnail_dir>images/thumbs/</thumbnail_dir>
  		<image_dir>images/big/</image_dir>
  		<slideshow_interval>5</slideshow_interval>
  		<pause_slideshow>false</pause_slideshow>
  		<rss_scale_images>true</rss_scale_images>
  		<background_music></background_music>
  		<background_music_volume>50</background_music_volume>
  		<link_images>false</link_images>
  		<disable_printscreen>false</disable_printscreen>
  	</config>
  	<albums>'
  
    # FIXME: some of these things need to be html_encode'd!!
    albums.each do |l|
  	s += '<album '
  	s += 'title="' + (l.name) + '"'
  	s += ' description="' + (l.name) + '"'
  	s += ' type="' + l.service + '"'
  	s += ' url="' + (l.url) + '"'
  	s += '>'
  	s += "</album>\n"
    end
  
    s += '</albums>
  	<language>
  		<string id="please wait" value="Please wait" />
  		<string id="loading" value="Loading" />
  		<string id="previous page" value="Previous Page" />
  		<string id="page % of %" value="Page % of %" />
  		<string id="next page" value="Next Page" />
  	</language>
  	</gallery>'
     file.write(s)
     file.close
  end

end

